@@ -26,7 +26,6 @@ class ScpiDevice(object):
     def execute(self, header: str, param: Optional[ScpiTypes] = None,
                 result: Optional[Type[ScpiTypes]] = type(None)) -> ScpiTypes:
         command = header
-        resp = None
         response = None
 
         if param is not None:
@@ -36,9 +35,10 @@ class ScpiDevice(object):
 
         if result is not type(None):
             response = result.parse(self.transport)
-            resp = str(response)
 
-        logger.info(f'exec [{type(param).__name__}] -> [{result.__name__ }]: <{command}> -> ({resp})')
+        logger.info(
+            f'exec [{type(param).__name__} -> {result.__name__}]: ' +
+            f'{str(header.encode())[1:]} ({str(param)}) -> ({str(response)})')
         return response
 
     def check_error(self) -> Optional[ScpiEvent]:
