@@ -1,5 +1,6 @@
 import socket
 import logging
+import re
 from urllib.parse import urlparse
 from typing import *
 from .scpi_transport_base import ScpiTransportBase
@@ -21,6 +22,7 @@ class ScpiTcpIpTransport(ScpiTransportBase):
     @classmethod
     def discover(cls,
                  dnssd_services: List[str] = ('_scpi-raw._tcp.local.',),
+                 dnssd_names: List[str] = ('.*',),
                  dnssd_timeout: float = 0.5) -> List[ScpiResource]:
         from zeroconf import Zeroconf, ServiceListener, ServiceBrowser
         import time
@@ -45,6 +47,9 @@ class ScpiTcpIpTransport(ScpiTransportBase):
 
         # Wait for some time to get answers
         time.sleep(dnssd_timeout)
+        print(dnssd_names)
+        # Patterns to check name against
+        patterns = [re.compile(pattern) for pattern in dnssd_names]
 
         return [ScpiResource(transport=ScpiTcpIpTransport,
                              location=f'dnssd:{service.name}',
@@ -57,13 +62,17 @@ class ScpiTcpIpTransport(ScpiTransportBase):
                              serialnum=service.properties[b'SerialNumber'].decode(
                                  'utf-8') if b'SerialNumber' in service.properties else None,
                              info=service
-                             ) for service in listener.services.values()]
+                             ) for service in listener.services.values()
+                if any([pattern.fullmatch(service.get_name()) for pattern in patterns])]
 
     def __init__(self, address: str, timeout: float = 5, **kwargs):
         super().__init__(**kwargs)
         self.logger = logging.getLogger(__name__)
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
+        self.socket.settimeout(timeout)
+        self.socket.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+
         # Get hostname and port
         addr = urlparse('//' + address)
         if (addr.hostname is None):
@@ -73,7 +82,6 @@ class ScpiTcpIpTransport(ScpiTransportBase):
             # Try to connect
             self.socket.connect((addr.hostname,
                                  addr.port if addr.port is not None else self.DEFAULT_PORT))
-            self.socket.settimeout(timeout)
 
             # Make a file interface for easier handling
             self.io = self.socket.makefile('rwb', buffering=0)
